peacockprint package
====================

Submodules
----------

peacockprint.peacockprint module
--------------------------------

.. automodule:: peacockprint.peacockprint
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: peacockprint
    :members:
    :undoc-members:
    :show-inheritance:
